﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.ParameterConfigurationTreeEncoding {
  [StorableClass]
  public class NullValueConfiguration : ValueConfiguration {

    public NullValueConfiguration() {
      this.ActualValue = new ConstrainedValue(null, null, null, true);
      this.IsOptimizable = false;
    }
    [StorableConstructor]
    protected NullValueConfiguration(bool deserializing) : base(deserializing) { }
    protected NullValueConfiguration(NullValueConfiguration original, Cloner cloner)
      : base(original, cloner) {
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new NullValueConfiguration(this, cloner);
    }

    public override string ToString() {
      return "null";
    }

    public override void Randomize(IRandom random) { }

    public override double CalculateSimilarity(IOptimizable optimizable) {
      return 1.0;
    }

    public override string ParameterInfoString {
      get { return "null"; }
    }

    public override void CollectOptimizedParameterNames(List<string> parameterNames, string prefix) { }

    public override List<IOptimizable> GetAllOptimizables() {
      return new List<IOptimizable>();
    }
  }
}
